@@ -1,12 +1,12 @@
-#!/usr/pkg/bin/python3.11
+#!/usr/pkg/bin/python3.13
 # -*- coding: utf-8 -*-
 
 """Utility for opening a file using the default application in a cross-platform
 manner. Modified from http://code.activestate.com/recipes/511443/.
 """
 
-__version__ = '1.1x'
-__all__ = ['open']
+__version__ = "1.1x"
+__all__ = ["open"]
 
 import os
 import sys
@@ -18,7 +18,7 @@ _open = None
 
 
 class BaseController(object):
-    '''Base class for open program controllers.'''
+    """Base class for open program controllers."""
 
     def __init__(self, name):
         self.name = name
@@ -28,14 +28,14 @@ class BaseController(object):
 
 
 class Controller(BaseController):
-    '''Controller for a generic open program.'''
+    """Controller for a generic open program."""
 
     def __init__(self, *args):
         super(Controller, self).__init__(os.path.basename(args[0]))
         self.args = list(args)
 
     def _invoke(self, cmdline):
-        if sys.platform[:3] == 'win':
+        if sys.platform[:3] == "win":
             closefds = False
             startupinfo = subprocess.STARTUPINFO()
             startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
@@ -43,9 +43,12 @@ class Controller(BaseController):
             closefds = True
             startupinfo = None
 
-        if (os.environ.get('DISPLAY') or sys.platform[:3] == 'win' or
-                                                    sys.platform == 'darwin'):
-            inout = file(os.devnull, 'r+')
+        if (
+            os.environ.get("DISPLAY")
+            or sys.platform[:3] == "win"
+            or sys.platform == "darwin"
+        ):
+            inout = file(os.devnull, "r+")
         else:
             # for TTY programs, we need stdin/out
             inout = None
@@ -53,19 +56,25 @@ class Controller(BaseController):
         # if possible, put the child precess in separate process group,
         # so keyboard interrupts don't affect child precess as well as
         # Python
-        setsid = getattr(os, 'setsid', None)
+        setsid = getattr(os, "setsid", None)
         if not setsid:
-            setsid = getattr(os, 'setpgrp', None)
+            setsid = getattr(os, "setpgrp", None)
 
-        pipe = subprocess.Popen(cmdline, stdin=inout, stdout=inout,
-                                stderr=inout, close_fds=closefds,
-                                preexec_fn=setsid, startupinfo=startupinfo)
+        pipe = subprocess.Popen(
+            cmdline,
+            stdin=inout,
+            stdout=inout,
+            stderr=inout,
+            close_fds=closefds,
+            preexec_fn=setsid,
+            startupinfo=startupinfo,
+        )
 
         # It is assumed that this kind of tools (gnome-open, kfmclient,
         # exo-open, xdg-open and open for OSX) immediately exit after launching
         # the specific application
         returncode = pipe.wait()
-        if hasattr(self, 'fixreturncode'):
+        if hasattr(self, "fixreturncode"):
             returncode = self.fixreturncode(returncode)
         return not returncode
 
@@ -82,10 +91,10 @@ class Controller(BaseController):
 
 
 # Platform support for Windows
-if sys.platform[:3] == 'win':
+if sys.platform[:3] == "win":
 
     class Start(BaseController):
-        '''Controller for the win32 start program through os.startfile.'''
+        """Controller for the win32 start program through os.startfile."""
 
         def open(self, filename):
             try:
@@ -97,14 +106,14 @@ if sys.platform[:3] == 'win':
             else:
                 return True
 
-    _controllers['windows-default'] = Start('start')
-    _open = _controllers['windows-default'].open
+    _controllers["windows-default"] = Start("start")
+    _open = _controllers["windows-default"].open
 
 
 # Platform support for MacOS
-elif sys.platform == 'darwin':
-    _controllers['open']= Controller('open')
-    _open = _controllers['open'].open
+elif sys.platform == "darwin":
+    _controllers["open"] = Controller("open")
+    _open = _controllers["open"].open
 
 
 # Platform support for Unix
@@ -119,20 +128,20 @@ else:
     from webbrowser import _iscommand
 
     class KfmClient(Controller):
-        '''Controller for the KDE kfmclient program.'''
+        """Controller for the KDE kfmclient program."""
 
-        def __init__(self, kfmclient='kfmclient'):
-            super(KfmClient, self).__init__(kfmclient, 'exec')
+        def __init__(self, kfmclient="kfmclient"):
+            super(KfmClient, self).__init__(kfmclient, "exec")
             self.kde_version = self.detect_kde_version()
 
         def detect_kde_version(self):
             kde_version = None
             try:
-                info = getoutput('kde-config --version')
+                info = getoutput("kde-config --version")
 
                 for line in info.splitlines():
-                    if line.startswith('KDE'):
-                        kde_version = line.split(':')[-1].strip()
+                    if line.startswith("KDE"):
+                        kde_version = line.split(":")[-1].strip()
                         break
             except (OSError, RuntimeError):
                 pass
@@ -140,49 +149,48 @@ else:
             return kde_version
 
         def fixreturncode(self, returncode):
-            if returncode is not None and self.kde_version > '3.5.4':
+            if returncode is not None and self.kde_version > "3.5.4":
                 return returncode
             else:
                 return os.EX_OK
 
     def detect_desktop_environment():
-        '''Checks for known desktop environments
+        """Checks for known desktop environments
 
         Return the desktop environments name, lowercase (kde, gnome, xfce)
         or "generic"
 
-        '''
+        """
 
-        desktop_environment = 'generic'
+        desktop_environment = "generic"
 
-        if os.environ.get('KDE_FULL_SESSION') == 'true':
-            desktop_environment = 'kde'
-        elif os.environ.get('GNOME_DESKTOP_SESSION_ID'):
-            desktop_environment = 'gnome'
+        if os.environ.get("KDE_FULL_SESSION") == "true":
+            desktop_environment = "kde"
+        elif os.environ.get("GNOME_DESKTOP_SESSION_ID"):
+            desktop_environment = "gnome"
         else:
             try:
-                info = getoutput('xprop -root _DT_SAVE_MODE')
+                info = getoutput("xprop -root _DT_SAVE_MODE")
                 if ' = "xfce4"' in info:
-                    desktop_environment = 'xfce'
+                    desktop_environment = "xfce"
             except (OSError, RuntimeError):
                 pass
 
         return desktop_environment
 
-
     def register_X_controllers():
-        if _iscommand('kfmclient'):
-            _controllers['kde-open'] = KfmClient()
+        if _iscommand("kfmclient"):
+            _controllers["kde-open"] = KfmClient()
 
-        for command in ('gnome-open', 'exo-open', 'xdg-open'):
+        for command in ("gnome-open", "exo-open", "xdg-open"):
             if _iscommand(command):
                 _controllers[command] = Controller(command)
 
     def get():
         controllers_map = {
-            'gnome': 'gnome-open',
-            'kde': 'kde-open',
-            'xfce': 'exo-open',
+            "gnome": "gnome-open",
+            "kde": "kde-open",
+            "xfce": "exo-open",
         }
 
         desktop_environment = detect_desktop_environment()
@@ -192,18 +200,17 @@ else:
             return _controllers[controller_name].open
 
         except KeyError:
-            if 'xdg-open' in _controllers:
-                return _controllers['xdg-open'].open
+            if "xdg-open" in _controllers:
+                return _controllers["xdg-open"].open
             else:
                 return webbrowser.open
 
-
     if os.environ.get("DISPLAY"):
         register_X_controllers()
     _open = get()
 
 
 def open(filename):
-    '''Open a file or a URL in the registered default application.'''
+    """Open a file or a URL in the registered default application."""
 
     return _open(filename)
